"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.IframeProvider = void 0;
const CrossWindowProvider_1 = require("@multiversx/sdk-web-wallet-cross-window-provider/out/CrossWindowProvider/CrossWindowProvider");
const errors_1 = require("@multiversx/sdk-web-wallet-cross-window-provider/out/errors");
const IframeManager_1 = require("../IframeManager/IframeManager");
class IframeProvider extends CrossWindowProvider_1.CrossWindowProvider {
    constructor() {
        super();
        this.windowManager = new IframeManager_1.IframeManager({
            onDisconnect: this.logout.bind(this)
        });
    }
    static getInstance() {
        if (!IframeProvider._instance) {
            IframeProvider._instance = new IframeProvider();
            return IframeProvider._instance;
        }
        return IframeProvider._instance;
    }
    init() {
        const _super = Object.create(null, {
            init: { get: () => super.init }
        });
        return __awaiter(this, void 0, void 0, function* () {
            const initialized = yield _super.init.call(this);
            yield this.windowManager.setWalletWindow();
            return initialized;
        });
    }
    login(options = {}) {
        const _super = Object.create(null, {
            login: { get: () => super.login }
        });
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            yield this.windowManager.setWalletWindow();
            const account = yield _super.login.call(this, options);
            if (!account.address) {
                (_a = this.windowManager.iframeWallet) === null || _a === void 0 ? void 0 : _a.remove();
                this.windowManager.walletWindow = null;
                throw new errors_1.ErrCouldNotLogin();
            }
            return account;
        });
    }
    dispose() {
        const _super = Object.create(null, {
            dispose: { get: () => super.dispose }
        });
        return __awaiter(this, void 0, void 0, function* () {
            return _super.dispose.call(this);
        });
    }
    logout() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.initialized) {
                throw new errors_1.ErrProviderNotInitialized();
            }
            try {
                this.ensureConnected();
                yield this.windowManager.closeConnection();
            }
            catch (e) {
                console.error(e);
            }
            this.initialized = false;
            this.disconnect();
            return true;
        });
    }
    signTransaction(transaction) {
        const _super = Object.create(null, {
            signTransaction: { get: () => super.signTransaction }
        });
        return __awaiter(this, void 0, void 0, function* () {
            yield this.windowManager.setWalletWindow();
            return _super.signTransaction.call(this, transaction);
        });
    }
    signTransactions(transactions) {
        const _super = Object.create(null, {
            signTransactions: { get: () => super.signTransactions }
        });
        return __awaiter(this, void 0, void 0, function* () {
            yield this.windowManager.setWalletWindow();
            return _super.signTransactions.call(this, transactions);
        });
    }
    guardTransactions(transactions) {
        const _super = Object.create(null, {
            guardTransactions: { get: () => super.guardTransactions }
        });
        return __awaiter(this, void 0, void 0, function* () {
            yield this.windowManager.setWalletWindow();
            return _super.guardTransactions.call(this, transactions);
        });
    }
    signMessage(message) {
        const _super = Object.create(null, {
            signMessage: { get: () => super.signMessage }
        });
        return __awaiter(this, void 0, void 0, function* () {
            yield this.windowManager.setWalletWindow();
            return _super.signMessage.call(this, message);
        });
    }
    openPopupConsent() {
        return __awaiter(this, void 0, void 0, function* () {
            return true;
        });
    }
}
IframeProvider._instance = null;
exports.IframeProvider = IframeProvider;
//# sourceMappingURL=IframeProvider.js.map